==> coreboot_4.15~dfsg.orig.tar.xz: coreboot-4.15/src/mainboard/hp/folio_9480m/hda_verb.c <==
/* SPDX-License-Identifier: GPL-2.0-only */

#include <device/azalia_device.h>

const u32 cim_verb_data[] = {
	0x10ec0280,	/* Codec Vendor / Device ID: Realtek */
	0x103c22db,	/* Subsystem ID */
	57,		/* Number of 4 dword sets */
	AZALIA_SUBVENDOR(0, 0x103c22db),
	AZALIA_RESET(1),
	AZALIA_PIN_CFG(0, 0x12, 0x90a60130),
	AZALIA_PIN_CFG(0, 0x13, 0x40000000),
	AZALIA_PIN_CFG(0, 0x14, 0x90170110),
	AZALIA_PIN_CFG(0, 0x15, 0x0321101f),
	AZALIA_PIN_CFG(0, 0x16, 0x411111f0),
	AZALIA_PIN_CFG(0, 0x17, 0x411111f0),
	AZALIA_PIN_CFG(0, 0x18, 0x411111f0),
	AZALIA_PIN_CFG(0, 0x19, 0x411111f0),
	AZALIA_PIN_CFG(0, 0x1a, 0x03a11020),
	AZALIA_PIN_CFG(0, 0x1b, 0x411111f0),
	AZALIA_PIN_CFG(0, 0x1d, 0x40738105),
	AZALIA_PIN_CFG(0, 0x1e, 0x411111f0),

	/* The following is from the OEM firmware */
	0x02050007, 0x0204c200, 0x02050063, 0x02044800,
	0x02050066, 0x02040809, 0x02050015, 0x02048842,
	0x0205000f, 0x0204cccc, 0x02050010, 0x0204ccdd,
	0x02050065, 0x02042000, 0x0205001c, 0x0204c900,
	0x02050018, 0x02043788, 0x02050008, 0x02048210,
	0x02050068, 0x02043022, 0x02050006, 0x02040800,
	0x02050061, 0x02040403, 0x02050061, 0x02040403,
	0x0205005f, 0x02040800, 0x02050060, 0x02040800,
	0x0205002c, 0x02044002, 0x0205002e, 0x02041ec4,
	0x0205002f, 0x02040000, 0x02050033, 0x0204c5e8,
	0x02050034, 0x02041a98, 0x02050035, 0x0204f5ad,
	0x02050036, 0x0204cbd2, 0x02050037, 0x02041605,
	0x02050038, 0x0204f5ad, 0x02050039, 0x0204ea5f,
	0x0205003a, 0x02040b42, 0x0205003b, 0x0204fb54,
	0x0205003c, 0x0204fcd9, 0x0205003d, 0x02040000,
	0x02050030, 0x02041f5c, 0x02050031, 0x02040111,
	0x02050032, 0x02041f5f, 0x0205003e, 0x02041ea9,
	0x0205002f, 0x02040000, 0x02050042, 0x0204c66e,
	0x02050043, 0x02041a29, 0x02050035, 0x0204f5ad,
	0x02050044, 0x0204ccdd, 0x02050045, 0x02041549,
	0x02050038, 0x0204f5ad, 0x02050046, 0x0204ee79,
	0x02050047, 0x020409f4, 0x0205003b, 0x0204fb54,
	0x02050048, 0x0204fa4c, 0x0205003d, 0x02040000,
	0x0205003f, 0x02041f4d, 0x02050040, 0x02040129,
	0x02050041, 0x02041f51, 0x02050049, 0x02041f61,
	0x0205002f, 0x02040000, 0x0205004d, 0x0204c2f4,
	0x0205004e, 0x02041d2e, 0x02050035, 0x0204f5ad,
	0x0205004f, 0x0204c5e8, 0x02050050, 0x02041a98,
	0x02050038, 0x0204f5ad, 0x02050051, 0x0204d30e,
	0x02050052, 0x020413e6, 0x0205003b, 0x0204fb54,
	0x02050053, 0x02040b73, 0x0205003d, 0x02040000,
	0x0205004a, 0x02041faf, 0x0205004b, 0x0204008a,
	0x0205004c, 0x02041fb0, 0x02050054, 0x02041fb0,
	0x0205002f, 0x02040000, 0x02050058, 0x0204c17a,
	0x02050059, 0x02041e8f, 0x02050035, 0x0204f5ad,
	0x0205005a, 0x0204c2f4, 0x0205005b, 0x02041d2e,
	0x02050038, 0x0204f5ad, 0x0205005c, 0x0204c899,
	0x0205005d, 0x0204195b, 0x0205003b, 0x0204fb54,
	0x0205005e, 0x02041444, 0x0205003d, 0x02040000,
	0x02050055, 0x02041fd8, 0x02050056, 0x02040045,
	0x02050057, 0x02041fd8, 0x0205002c, 0x0204ffc2,
	0x02050026, 0x02042828, 0x02050029, 0x02040250,
	0x02050004, 0x0204c09e, 0x0205000e, 0x02045001,
};

const u32 pc_beep_verbs[0] = {};

AZALIA_ARRAY_SIZES;

==> coreboot_24.12+dfsg.orig.tar.xz: coreboot-24.12/src/mainboard/hp/folio_9480m/hda_verb.c <==
/* SPDX-License-Identifier: GPL-2.0-only */

#include <device/azalia_device.h>

const u32 cim_verb_data[] = {
	0x10ec0280,	/* Codec Vendor / Device ID: Realtek */
	0x103c22db,	/* Subsystem ID */
	57,		/* Number of 4 dword sets */
	AZALIA_SUBVENDOR(0, 0x103c22db),
	AZALIA_RESET(1),
	AZALIA_PIN_CFG(0, 0x12, 0x90a60130),
	AZALIA_PIN_CFG(0, 0x13, 0x40000000),
	AZALIA_PIN_CFG(0, 0x14, 0x90170110),
	AZALIA_PIN_CFG(0, 0x15, 0x0321101f),
	AZALIA_PIN_CFG(0, 0x16, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x17, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x18, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x19, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x1a, 0x03a11020),
	AZALIA_PIN_CFG(0, 0x1b, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x1d, 0x40738105),
	AZALIA_PIN_CFG(0, 0x1e, AZALIA_PIN_CFG_NC(0)),

	/* The following is from the OEM firmware */
	0x02050007, 0x0204c200, 0x02050063, 0x02044800,
	0x02050066, 0x02040809, 0x02050015, 0x02048842,
	0x0205000f, 0x0204cccc, 0x02050010, 0x0204ccdd,
	0x02050065, 0x02042000, 0x0205001c, 0x0204c900,
	0x02050018, 0x02043788, 0x02050008, 0x02048210,
	0x02050068, 0x02043022, 0x02050006, 0x02040800,
	0x02050061, 0x02040403, 0x02050061, 0x02040403,
	0x0205005f, 0x02040800, 0x02050060, 0x02040800,
	0x0205002c, 0x02044002, 0x0205002e, 0x02041ec4,
	0x0205002f, 0x02040000, 0x02050033, 0x0204c5e8,
	0x02050034, 0x02041a98, 0x02050035, 0x0204f5ad,
	0x02050036, 0x0204cbd2, 0x02050037, 0x02041605,
	0x02050038, 0x0204f5ad, 0x02050039, 0x0204ea5f,
	0x0205003a, 0x02040b42, 0x0205003b, 0x0204fb54,
	0x0205003c, 0x0204fcd9, 0x0205003d, 0x02040000,
	0x02050030, 0x02041f5c, 0x02050031, 0x02040111,
	0x02050032, 0x02041f5f, 0x0205003e, 0x02041ea9,
	0x0205002f, 0x02040000, 0x02050042, 0x0204c66e,
	0x02050043, 0x02041a29, 0x02050035, 0x0204f5ad,
	0x02050044, 0x0204ccdd, 0x02050045, 0x02041549,
	0x02050038, 0x0204f5ad, 0x02050046, 0x0204ee79,
	0x02050047, 0x020409f4, 0x0205003b, 0x0204fb54,
	0x02050048, 0x0204fa4c, 0x0205003d, 0x02040000,
	0x0205003f, 0x02041f4d, 0x02050040, 0x02040129,
	0x02050041, 0x02041f51, 0x02050049, 0x02041f61,
	0x0205002f, 0x02040000, 0x0205004d, 0x0204c2f4,
	0x0205004e, 0x02041d2e, 0x02050035, 0x0204f5ad,
	0x0205004f, 0x0204c5e8, 0x02050050, 0x02041a98,
	0x02050038, 0x0204f5ad, 0x02050051, 0x0204d30e,
	0x02050052, 0x020413e6, 0x0205003b, 0x0204fb54,
	0x02050053, 0x02040b73, 0x0205003d, 0x02040000,
	0x0205004a, 0x02041faf, 0x0205004b, 0x0204008a,
	0x0205004c, 0x02041fb0, 0x02050054, 0x02041fb0,
	0x0205002f, 0x02040000, 0x02050058, 0x0204c17a,
	0x02050059, 0x02041e8f, 0x02050035, 0x0204f5ad,
	0x0205005a, 0x0204c2f4, 0x0205005b, 0x02041d2e,
	0x02050038, 0x0204f5ad, 0x0205005c, 0x0204c899,
	0x0205005d, 0x0204195b, 0x0205003b, 0x0204fb54,
	0x0205005e, 0x02041444, 0x0205003d, 0x02040000,
	0x02050055, 0x02041fd8, 0x02050056, 0x02040045,
	0x02050057, 0x02041fd8, 0x0205002c, 0x0204ffc2,
	0x02050026, 0x02042828, 0x02050029, 0x02040250,
	0x02050004, 0x0204c09e, 0x0205000e, 0x02045001,
};

const u32 pc_beep_verbs[0] = {};

AZALIA_ARRAY_SIZES;
